<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * woo_projects_simplicity_content_start 
 * Wraps all projects content in wrappers which match the theme markup
 * @since   1.12.0
 * @return  void
 * @uses  	woo_content_before(), woo_main_before()
 */

if ( ! function_exists( 'woo_projects_simplicity_content_start' ) ) {
	function woo_projects_simplicity_content_start() {
		?>
		<!-- #content Starts -->
		<div id="content" class="page col-full">
			<div id="main" class="fullwidth"> 		          
				<div id="projects" class="col-full">
	    <?php
	} // End woo_projects_simplicity_content_start()
}

/**
 * woo_projects_after_content 
 * Closes the wrapping divs after the project content
 * @since   1.12.0
 * @return  void
 * @uses    woo_main_after(), do_action(), woo_content_after()
 */
if ( ! function_exists( 'woo_projects_after_content' ) ) {
	function woo_projects_after_content() {
		?>
				</div> <!-- / end #projects-->
			</div> <!-- / end #content-->
		</div><!-- / end #main-->		          
	    <?php
	} // End woo_projects_after_content()
}

/**
 * Add the projects page title markup 
 *
 * @since   1.12.0
 * @return  void
 * @uses  	woo_content_before(), woo_main_before()
 */
if ( ! function_exists( 'woo_projects_archive_title' ) ) {
	function woo_projects_archive_title() {
		global $woo_options;
		?>
		<!-- #title-container Starts -->
		<div id="title-container">

			<?php 
			if( is_single() && is_array( $woo_options ) && isset( $woo_options['woo_single_portfolio_title'] ) ){
				$title = $woo_options[ 'woo_single_portfolio_title' ];
			}else{
				$title = __('Projects','woothemes'); 
			}
			?>
	  		<h1 class="title col-full"><?php echo  $title; ?> </h1>
		</div>

	    <?php
	} // End woo_projects_archive_title()
}

/**
 * Loop columns number
 * Changes default value from 2 to 4
 * @since   1.12.0
 * @return  void
 *
 */
if ( ! function_exists( 'woo_custom_projects_loop_columns' ) ) {
	function woo_custom_projects_loop_columns( $columns ) {		
		$columns = 4;
		return $columns;
	}
}

/**
 * Enqueue styles and scripts
 *
 * @since   1.12.0
 * @return  void
 *
 */
if ( ! function_exists( 'woo_projects_scripts' ) ) {
	function woo_projects_scripts( ) {		
		global $integrations_url;

		//setup projects url 
		$projects_url = $integrations_url . 'projects/';

		// setup projects ccs
		$projects_lightbox_css = $projects_url . '/css/lightbox.css';
		$projects_css = $projects_url . '/css/projects.css';
		
		wp_enqueue_style('projects-lightbox-css', $projects_lightbox_css  );
		wp_enqueue_style('simplicity-projects-css', $projects_css  );

		//setup project javascript
		$projects_lightbox_js = $projects_url . '/js/lightbox.min.js';
		wp_enqueue_script( 'projects-lightbox-js', $projects_lightbox_js, array('jquery') , true );

	}
}

/**
 * Limiting the words excerpt
 *
 * @since   1.12.0
 * @return  string $excerpt
 *
 */

if ( ! function_exists( 'woo_custom_projects_limit_excerpt' ) ) {
	function woo_custom_projects_limit_excerpt( $excerpt ) {		

		if( is_post_type_archive('project') ){
			$excerpt = wp_trim_words( $excerpt, 15 , '' );
			$excerpt = $excerpt . '...';
		}

		return $excerpt;
	}
}

/**
 * alter the sinlge image holder div
 * @since   1.0.0
 * @return  void
 * @uses    do_action()
 */
if ( ! function_exists( 'woo_custom_projects_single_images_holder' ) ) {
	function woo_custom_projects_single_images_holder() {
		?>
			<div id="images" >
				<?php
					/**
					 * woo_custom_projects_inside_single_images_holder
				 	 * @hooked projects_template_single_feature - 10
				 	 * @hooked projects_template_single_gallery - 20
					 */
					do_action( 'woo_custom_projects_inside_single_images_holder' );
				?>
			</div> <!-- / end #images -->

		<?php
	}
}

/**
 *  Custom template file loading for  single project gallery  
 *
 * @since   1.12.0
 * @return  void
 */
if ( ! function_exists( 'woo_custom_projects_template_single_gallery' ) ) {
	function woo_custom_projects_template_single_gallery() {
	  	global $integrations_path , $woo_options;

	  	$templates_path = $integrations_path . 'projects/templates/';
	  	$gallery_file_path = $templates_path . 'single-project-gallery.php';

	  	if( is_array( $woo_options ) 
	  		&& isset( $woo_options['woo_portfolio_gallery'] ) 
	  		&& 'true' == $woo_options['woo_portfolio_gallery'] ){

	  		//load the galler template file:
	  		require_once( $gallery_file_path );
	  	}  	
	}
}

/**
 *  Custom template file loading for  single project feature image
 *
 * @since   1.12.0
 * @return  void
 */
if ( ! function_exists( 'woo_custom_projects_template_single_feature' ) ) {
	function woo_custom_projects_template_single_feature() {
	  	global $integrations_path;

	  	$templates_path = $integrations_path . 'projects/templates/';
	  	$feature_file_path = $templates_path . 'single-project-feature.php';

	  	require_once( $feature_file_path );
	}
}


/**
 *  Load the archive project thumnail inside its own anchor 
 *
 * @since   1.12.0
 * @return  void
 */

if ( ! function_exists( 'woo_custom_template_loop_project_thumbnail' ) ) {
	function woo_custom_template_loop_project_thumbnail() {
		?>
	  	<a href="<?php the_permalink(); ?>" class="project-thumbnail-permalink">
		  	<?php echo  projects_get_project_thumbnail() ; ?>
		</a>
		<?php
	}	
}

/**
 *  Change number of products per page
 *
 * @since   1.12.0
 * @return  $args
 */

if ( ! function_exists( 'woo_custom_projects_per_page' ) ) {
	function woo_custom_projects_per_page( $wp_query ) {
			if( 'project' == $wp_query->query['post_type'] 
				&& is_post_type_archive() ){
				$wp_query->query_vars['posts_per_page'] = 12;
			}
			return $wp_query;
	}	
}

/**
* hide the sidebar on single projects 
*
* @since 1.12.0
*/

add_filter( 'is_active_sidebar','woo_remove_sidebar_single_project', 80 );

function woo_remove_sidebar_single_project(){
	if( is_singular( 'project' ) ){
		return false;
	}else{
		return true;
	}
}// end woo_remove_sidebar_single_project
